@@ -266,7 +266,7 @@ class Handler(tornado.web.RequestHandler):
 
             self.write("<tr><td>%s</td><td>%s</td><td>%s</td><td>%s</td><td>%s</td></tr>" %
                        (push["status"], push["commit"], push["author"],
-                        completed, (completed - started).seconds))
+                        completed, (completed - started).seconds) if completed else "waiting")
         self.write("</table>")
 
     def json(self, obj, status=None):
